@@ -1,6 +1,6 @@
 import datetime
 from python_helper.api.src.domain import Constant as c
-from python_helper.api.src.service import ObjectHelper, StringHelper, RandomHelper
+from python_helper.api.src.service import ObjectHelper, StringHelper, RandomHelper, LogHelper
 
 DEFAULT_DATETIME_PATTERN = '%Y-%m-%d %H:%M:%S'
 DEFAULT_DATE_PATTERN = '%Y-%m-%d'
@@ -35,17 +35,17 @@ DEFAULT_TIME_BEGIN = '00:00:00'
 DEFAULT_TIME_END = '23:59:59'
 
 
-def toString(givenDatetime, pattern=DEFAULT_DATETIME_PATTERN) :
+def toString(givenDatetime, pattern=DEFAULT_DATETIME_PATTERN):
     return givenDatetime if ObjectHelper.isNone(givenDatetime) or isinstance(givenDatetime, str) else parseToString(givenDatetime, pattern=pattern)
 
-def parseToString(given, pattern=DEFAULT_DATETIME_PATTERN) :
+def parseToString(given, pattern=DEFAULT_DATETIME_PATTERN):
     # return str(parseToPattern(str(given), pattern=pattern))
     # return str(given)
     return str(forcedlyParse(str(given), pattern=pattern))
 
-def parseToPattern(given, pattern=DEFAULT_DATETIME_PATTERN, timedelta=False) :
+def parseToPattern(given, pattern=DEFAULT_DATETIME_PATTERN, timedelta=False):
     given = given.strip()
-    if StringHelper.isNotBlank(given) :
+    if StringHelper.isNotBlank(given):
         parsed = datetime.datetime.strptime(given, pattern)
         if timedelta and pattern in TIME_PATTERNS :
             return timeDelta(hours=parsed.hour, minutes=parsed.minute, seconds=parsed.second, milliseconds=parsed.millisecond, microseconds=parsed.microsecond)
@@ -56,7 +56,7 @@ def parseToPattern(given, pattern=DEFAULT_DATETIME_PATTERN, timedelta=False) :
         elif pattern in TIME_PATTERNS :
             return parsed.time()
 
-def forcedlyParse(given, pattern=DEFAULT_DATETIME_PATTERN, timedelta=False) :
+def forcedlyParse(given, pattern=DEFAULT_DATETIME_PATTERN, timedelta=False):
     parsed = None
     for pattern in [pattern, *PATTERNS] :
         try :
@@ -66,42 +66,42 @@ def forcedlyParse(given, pattern=DEFAULT_DATETIME_PATTERN, timedelta=False) :
             pass
     return parsed
 
-def parseToDateTime(givenDatetime, pattern=DEFAULT_DATETIME_PATTERN) :
+def parseToDateTime(givenDatetime, pattern=DEFAULT_DATETIME_PATTERN):
     return givenDatetime if ObjectHelper.isNone(givenDatetime) or not isinstance(givenDatetime, str) else parseToPattern(givenDatetime, pattern=pattern)
 
-def forcedlyGetDateTime(givenDatetime, pattern=DEFAULT_DATETIME_PATTERN) :
+def forcedlyGetDateTime(givenDatetime, pattern=DEFAULT_DATETIME_PATTERN):
     return givenDatetime if ObjectHelper.isNone(givenDatetime) or not isinstance(givenDatetime, str) else forcedlyParse(givenDatetime, pattern=pattern)
 
-def forcedlyGetDate(givenDate, pattern=DEFAULT_DATE_PATTERN) :
+def forcedlyGetDate(givenDate, pattern=DEFAULT_DATE_PATTERN):
     return givenDate if ObjectHelper.isNone(givenDate) or not isinstance(givenDate, str) else forcedlyParse(givenDate, pattern=pattern)
 
-def forcedlyGetTime(givenTime, pattern=DEFAULT_TIME_PATTERN) :
+def forcedlyGetTime(givenTime, pattern=DEFAULT_TIME_PATTERN):
     return givenTime if ObjectHelper.isNone(givenTime) or not isinstance(givenTime, str) else forcedlyParse(givenTime, pattern=pattern)
 
-def forcedlyGetInterval(givenTime, pattern=DEFAULT_DATETIME_PATTERN) :
+def forcedlyGetInterval(givenTime, pattern=DEFAULT_DATETIME_PATTERN):
     return givenTime if ObjectHelper.isNone(givenTime) or not isinstance(givenTime, str) else forcedlyParse(givenTime, pattern=pattern, timedelta=True)
 
 def timeDelta(days=0, hours=0, minutes=0, seconds=0, milliseconds=0, microseconds=0, **kwargs):
     return datetime.timedelta(days=days, hours=hours, minutes=minutes, seconds=seconds, milliseconds=milliseconds, microseconds=microseconds, **kwargs)
 
-def dateTimeNow() :
+def dateTimeNow():
     # return datetime.datetime.utcnow()
     return datetime.datetime.now()
 
-def now() :
+def now():
     return dateTimeNow()
 
-def dateOf(dateTime=None, pattern=DEFAULT_DATE_PATTERN) :
+def dateOf(dateTime=None, pattern=DEFAULT_DATE_PATTERN):
     return dateTime.date()
 
-def timeOf(dateTime=None, pattern=DEFAULT_TIME_PATTERN) :
+def timeOf(dateTime=None, pattern=DEFAULT_TIME_PATTERN):
     return dateTime.time()
 
-def dateNow() :
+def dateNow():
     # datetime.date.today()
     return dateOf(dateTime=dateTimeNow())
 
-def timeNow() :
+def timeNow():
     return timeOf(dateTime=dateTimeNow())
 
 def timestampNow():
@@ -139,79 +139,73 @@ def of(dateTime=None, date=None, time=None, pattern=DEFAULT_DATETIME_PATTERN):
 def timestampOf(dateTime=None, date=None, time=None, pattern=DATETIME_FULL_PATTERN):
     return datetime.datetime.timestamp(of(date=date, time=time, dateTime=dateTime, pattern=pattern))
 
-def plusSeconds(givenDateTimeOrTime, seconds=None, deltaInSeconds=None) :
-    if ObjectHelper.isNotNone(seconds) :
+def plusSeconds(givenDateTimeOrTime, seconds=None, deltaInSeconds=None):
+    if ObjectHelper.isNotNone(seconds):
         deltaInMinutes = timeDelta(seconds=seconds)
-    if isinstance(givenDateTimeOrTime, datetime.time) :
+    if isinstance(givenDateTimeOrTime, datetime.time):
         givenDateTimeOrTime = forcedlyParse(f'{str(dateNow())} {givenDateTimeOrTime}')
     return forcedlyGetDateTime(str(givenDateTimeOrTime)) + deltaInMinutes
 
-def minusSeconds(givenDateTimeOrTime, seconds=None, deltaInSeconds=None) :
-    if ObjectHelper.isNotNone(seconds) :
+def minusSeconds(givenDateTimeOrTime, seconds=None, deltaInSeconds=None):
+    if ObjectHelper.isNotNone(seconds):
         deltaInMinutes = timeDelta(seconds=seconds)
-    if isinstance(givenDateTimeOrTime, datetime.time) :
+    if isinstance(givenDateTimeOrTime, datetime.time):
         givenDateTimeOrTime = forcedlyParse(f'{str(dateNow())} {givenDateTimeOrTime}')
     return forcedlyGetDateTime(str(givenDateTimeOrTime)) - deltaInMinutes
 
-def plusMinutes(givenDateTimeOrTime, minutes=None, deltaInMinutes=None) :
-    if ObjectHelper.isNotNone(minutes) :
+def plusMinutes(givenDateTimeOrTime, minutes=None, deltaInMinutes=None):
+    if ObjectHelper.isNotNone(minutes):
         deltaInMinutes = timeDelta(seconds=minutes*60)
-    if isinstance(givenDateTimeOrTime, datetime.time) :
+    if isinstance(givenDateTimeOrTime, datetime.time):
         givenDateTimeOrTime = forcedlyParse(f'{str(dateNow())} {givenDateTimeOrTime}')
     return forcedlyGetDateTime(str(givenDateTimeOrTime)) + deltaInMinutes
 
-def minusMinutes(givenDateTimeOrTime, minutes=None, deltaInMinutes=None) :
-    if ObjectHelper.isNotNone(minutes) :
+def minusMinutes(givenDateTimeOrTime, minutes=None, deltaInMinutes=None):
+    if ObjectHelper.isNotNone(minutes):
         deltaInMinutes = timeDelta(minutes=minutes)
-    if isinstance(givenDateTimeOrTime, datetime.time) :
+    if isinstance(givenDateTimeOrTime, datetime.time):
         givenDateTimeOrTime = forcedlyParse(f'{str(dateNow())} {givenDateTimeOrTime}')
     return forcedlyGetDateTime(str(givenDateTimeOrTime)) - deltaInMinutes
 
-def plusDays(givenDay, days=None, deltaInDays=None) :
-    if ObjectHelper.isNotNone(days) :
+def plusDays(givenDay, days=None, deltaInDays=None):
+    if ObjectHelper.isNotNone(days):
         deltaInDays = timeDelta(days=days)
     return forcedlyGetDateTime(str(givenDay)) + deltaInDays
 
-def minusDays(givenDay, days=None, deltaInDays=None) :
-    if ObjectHelper.isNotNone(minutes) :
+def minusDays(givenDay, days=None, deltaInDays=None):
+    if ObjectHelper.isNotNone(minutes):
         deltaInDays = timeDelta(days=days)
     return forcedlyGetDateTime(str(givenDay)) - deltaInDays
 
-def getDefaultTimeBegin() :
+def getDefaultTimeBegin():
     return forcedlyGetTime(DEFAULT_TIME_BEGIN)
 
-def getDatetimeMonthBegin() :
+def getDatetimeMonthBegin():
     return parseToPattern(c.SPACE.join([c.DASH.join(str(dateTimeNow()).split()[0].split(c.DASH)[:-1] + ['01']), DEFAULT_TIME_BEGIN]))
 
-def getTodayDateAndTodayTime() :
+def getTodayDateAndTodayTime():
     dateTime = dateTimeNow()
     return dateOf(dateTime=dateTime), timeOf(dateTime=dateTime)
 
-def getTodayDateTimeBegin() :
+def getTodayDateTimeBegin():
     return parseToDateTime(f'{dateNow()} {DEFAULT_TIME_BEGIN}')
 
-def getTodayDateTimeEnd() :
+def getTodayDateTimeEnd():
     return parseToDateTime(f'{dateNow()} {DEFAULT_TIME_END}')
 
 ###- deprecated
-def getWeekDay(ofDatetime=None, ofDate=None, ofTime=None) :
-    log.warning(getWeekDay, 'This is deprecated')
-    if ObjectHelper.isNotNone(ofDatetime) :
-        return forcedlyGetDateTime(ofDatetime).weekday()
-    elif ObjectHelper.isNotNone(ofDate) and ObjectHelper.isNotNone(ofTime) :
-        return of(forcedlyGetDate(ofDate), forcedlyGetTime(ofTime)).weekday()
-    elif ObjectHelper.isNotNone(ofDate) :
-        return of(forcedlyGetDate(ofDate), forcedlyGetTime(DEFAULT_TIME_END)).weekday()
-    return dateTimeNow().weekday()
-
-def getWeekDayOf(dateTime=None, date=None, time=None) :
-    if ObjectHelper.isNotNone(dateTime) :
+def getWeekDay(dateTime=None, date=None, time=None):
+    if ObjectHelper.isNotNone(dateTime):
         return forcedlyGetDateTime(dateTime).weekday()
-    elif ObjectHelper.isNotNone(date) and ObjectHelper.isNotNone(time) :
-        return of(forcedlyGetDate(date), forcedlyGetTime(time)).weekday()
-    elif ObjectHelper.isNotNone(date) :
-        return of(forcedlyGetDate(date), forcedlyGetTime(DEFAULT_TIME_END)).weekday()
+    elif ObjectHelper.isNotNone(date) and ObjectHelper.isNotNone(time):
+        return of(date=forcedlyGetDate(date), time=forcedlyGetTime(time)).weekday()
+    elif ObjectHelper.isNotNone(date):
+        return of(date=forcedlyGetDate(date), time=forcedlyGetTime(DEFAULT_TIME_END)).weekday()
     return dateTimeNow().weekday()
 
-def addNoise(givenDatetime) :
+def getWeekDayOf(dateTime=None, date=None, time=None):
+    '''Repetition of getWeekDay, just for semantic'''
+    return getWeekDay(dateTime=dateTime, date=date, time=time)
+
+def addNoise(givenDatetime):
     return givenDatetime + timeDelta(milliseconds=RandomHelper.integer(0,999))
